import { ensureTailwind } from './ensure-tailwind.js';
import { installFlowbiteReact } from './install.js';
import { patchTailwind } from './patch.js';
import { setupClassList } from './setup-class-list.js';
import { setupConfig } from './setup-config.js';
import { setupGitIgnore } from './setup-gitignore.js';
import { setupOutputDirectory } from './setup-output-directory.js';
import { setupPatch } from './setup-patch.js';
import { setupPlugin } from './setup-plugin.js';
import { setupRegister } from './setup-register.js';
import { setupTailwind } from './setup-tailwind.js';
import { setupVSCode } from './setup-vscode.js';

async function init() {
  try {
    await ensureTailwind();
    await patchTailwind();
    await installFlowbiteReact();
    await setupPatch();
    await setupTailwind();
    await setupOutputDirectory();
    await setupClassList();
    await setupConfig();
    await setupGitIgnore();
    await setupVSCode();
    const hasBundler = await setupPlugin();
    if (!hasBundler) {
      await setupRegister();
    }
    console.log("\n\u2705 Flowbite React has been successfully initialized!");
  } catch (error) {
    console.error("An error occurred during initialization:", error);
    process.exit(1);
  }
}

export { init };
//# sourceMappingURL=init.js.map
