'use strict';

var fs = require('fs/promises');
var cjson = require('comment-json');
var consts = require('../consts.cjs');
var getPackageJson = require('../utils/get-package-json.cjs');

async function setupPatch() {
  try {
    const patchCommand = "flowbite-react patch";
    const packageJson = await getPackageJson.getPackageJson();
    if (!packageJson.scripts) {
      packageJson.scripts = {};
    }
    if (!packageJson.scripts.postinstall?.includes(patchCommand)) {
      console.log(`Adding postinstall patch script to ${consts.packageJsonFile}...`);
      if (packageJson.scripts.postinstall) {
        packageJson.scripts.postinstall += ` && ${patchCommand}`;
      } else {
        packageJson.scripts.postinstall = patchCommand;
      }
      await fs.writeFile(consts.packageJsonFile, cjson.stringify(packageJson, null, 2), { flag: "w" });
    }
  } catch (error) {
    console.error(`Failed to setup ${consts.packageJsonFile}:`, error);
  }
}

exports.setupPatch = setupPatch;
//# sourceMappingURL=setup-patch.cjs.map
