import fs__default from 'fs/promises';
import cjson from 'comment-json';
import { packageJsonFile } from '../consts.js';
import { getPackageJson } from '../utils/get-package-json.js';

async function setupPatch() {
  try {
    const patchCommand = "flowbite-react patch";
    const packageJson = await getPackageJson();
    if (!packageJson.scripts) {
      packageJson.scripts = {};
    }
    if (!packageJson.scripts.postinstall?.includes(patchCommand)) {
      console.log(`Adding postinstall patch script to ${packageJsonFile}...`);
      if (packageJson.scripts.postinstall) {
        packageJson.scripts.postinstall += ` && ${patchCommand}`;
      } else {
        packageJson.scripts.postinstall = patchCommand;
      }
      await fs__default.writeFile(packageJsonFile, cjson.stringify(packageJson, null, 2), { flag: "w" });
    }
  } catch (error) {
    console.error(`Failed to setup ${packageJsonFile}:`, error);
  }
}

export { setupPatch };
//# sourceMappingURL=setup-patch.js.map
